@@ -6,39 +6,41 @@
 """Utilities for formatting and outputting records."""
 
 import json
-import sys
+import io
 
 
-def line_formatter(dct, output_stream):
+def line_formatter(dct):
     """Formats a dictionary `dct` into one line and prints it to the
 `output_stream`.
 
 Values in `dct` are written one after the other, separated by the string
 ',\\t'. The whole line is surrounded by square brackets."""
-    print("[", end="", file=output_stream)
+
+    output = io.StringIO()
+    print("[", end="", file=output)
     first = True
     for k, v in dct.items():
         if first:
-            print("{}".format(v), end="", file=output_stream)
+            print("{}".format(v), end="", file=output)
             first = False
         else:
-            print(",\t{}".format(v), end="", file=output_stream)
-    print("]", file=output_stream)
+            print(",\t{}".format(v), end="", file=output)
+    print("]", end="", file=output)
+
+    return output.getvalue()
 
 
-def raw_formatter(obj, output_stream):
+def raw_formatter(obj):
     """Prints the argument `obj` argument to the `output_stream` without further
 formatting."""
-    print(obj, file=output_stream)
+    return obj
 
 
-def json_formatter(dct, output_stream):
+def json_formatter(dct):
     """Creates a JSON string from the given dictionary (`dct`) and prints it to the
 given `output_stream`."""
-    json.dump(dct, output_stream)
-    print("", file=output_stream)
+    return json.dumps(dct)
 
 
-def json_formatter_pretty(dct, output_stream):
-    json.dump(dct, output_stream, indent=2)
-    print("", file=output_stream)
+def json_formatter_pretty(dct):
+    return json.dumps(dct, indent=2)
