@@ -3,6 +3,7 @@
 # distributed with this file, You can obtain one at
 # https://mozilla.org/MPL/2.0/.
 
+"""Tools used for parsing the MonetDB profiler output"""
 
 import json
 import sys
@@ -14,7 +15,8 @@ def parser_wrapper(json_str):
     try:
         return json.loads(json_str)
     except Exception as e:
-        print(f"Parsing failed for {json_str} ({e})", file=sys.stderr)
+        print("Parsing failed for {} ({})".format(json_str, e),
+              file=sys.stderr)
         return dict()
 
 
